# Set up parameters and perform simulation
# Parameters:
#  bc: Length or recording array (number of barcodes)
#. mu: Edit rate
#. g: Depth of the tree

# Fig1 parameter variation: edit rate
# Result: three state recording robustly under a range of edit rates. Accuracy is higher overall compare to a two-state recording model.

# Run simulations (by default in parallel using %dopar% if supported)
# Returns a list of lists with the accuracy for each parameter set


library(tidyr)
library(ggplot2)
library(dplyr)
# generates genData object:
# Uncomment to run all simulations from scratch, depending on the parameters and depth of the tree it could take several minutes to several hours
# See the main simulation code for information on how to run simulations
# source("simulationEnsemble.R")

# For Fig1C we ran a simulation changing several parameters:
# Depth of the tree in number of cell divisions (generations) 3,4,5
# The length of the memoir array in number of barcodes 10, 16, 24, 38, 60

# Load simulation data
load("simulationFig1B_bitVStrit_3and4_generations.rdata")

# From pre-computed simulations of the int-memoir array:
generations = c(3,4,5)
barcodes = c(10,16,24,38,60)

# Make tidy data frame from genData object:
# generations and barcodes come from the simulationEnsemble.R
# Use the same parameter ranges that were used in the simulation
genDataTidy<-function(genData,generations,barcodes){
        tidy_output = data.frame()
        for(g in generations){
            for(bc in barcodes){
                this_series = unlist( lapply(genData[[g]][[bc]], function(x){mean(x[,2])} ))
                this_df = data.frame(scores = this_series, bc = rep(bc,length(this_series)), mu = as.numeric(names(this_series)), gen = rep(g,length(this_series)))
                tidy_output =rbind(tidy_output,this_df)
            }
        }
        return(tidy_output)
}

genData_trit = genData_trit
genData_trit %>% genDataTidy(generations = generations,barcodes = barcodes) -> trit_tidy

x11();
trit_tidy %>% group_by(gen) %>%
							ggplot(aes(x = mu, y = scores, group = gen, color = gen)) +
							geom_line() + geom_point() + ylim(0,1)  +
							theme_classic() + theme(text = element_text(size = 30)) +
							facet_grid(~bc)


# Run for bit:
# Same script but with simulationType = 'binary'
genData_bit = genData_bit
genData_bit %>% genDataTidy(generations = generations,barcodes = barcodes) -> bit_tidy


bit_tidy %>% group_by(gen) %>%
    ggplot(aes(x = mu, y = scores, group = gen, color = gen)) +
    geom_line() + geom_point() + ylim(0,1)  +
    theme_classic() + theme(text = element_text(size = 30)) +
    facet_grid(~bc)



# Make a combined plot
bit_tidy$type = rep('Bit',dim(bit_tidy)[1])
trit_tidy$type = rep('Trit', dim(trit_tidy)[1])

all_data = rbind(trit_tidy,bit_tidy)

all_data %>% filter(gen %in% c(3,4)) %>% filter(bc==10) %>%
						  group_by(gen) %>% ggplot(aes(x = mu,y=scores, group= type, color = type)) +
							geom_line(size = 1.5) + geom_point(size = 4) + ylim(0,1)  +
							theme_classic() + theme(text = element_text(size = 30)) +
							facet_grid(rows  = vars(gen))
